client

package
v0.0.0-...-dfd1872 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2025 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client interface {
	// Publish messages to broker
	Publish(topic string, data []byte) error

	// Subscribe over broker
	Subscribe(topic string, handler internal.MessageHandler)

	// Unsubscribe from broker
	Unsubscribe(topic string)
}

Client is our client handler which enables a user to communicate with broker server.

func NewClient

func NewClient(uri string) (Client, error)

NewClient creates a new client to connect to broker server.

Directories

Path Synopsis
examples
complex command
simple command

Jump to